#
# spec file for package avogadrolibs
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%if 0%{suse_version} >= 1550
%bcond_without spglib
%bcond_without python
%else
%bcond_with spglib
%bcond_with python
%endif

# Requires genXrdPattern
%bcond_with vtk

%define sonum 1
%define libname libAvogadro%{sonum}
%define molecules_rev 1.98.0
%define crystals_rev  1.98.0
Name:           avogadrolibs
Version:        1.98.1
Release:        bp160.1.9
Summary:        Avogadro libraries for computational chemistry
License:        BSD-3-Clause AND CDDL-1.0 AND GPL-3.0-or-later AND Apache-2.0
URL:            https://two.avogadro.cc/
Source0:        https://github.com/OpenChemistry/avogadrolibs/archive/%{version}.tar.gz#/%{name}-%{version}.tar.gz
Source1:        https://github.com/OpenChemistry/molecules/archive/%{molecules_rev}.tar.gz#/molecules-%{molecules_rev}.tar.gz
Source2:        https://github.com/OpenChemistry/crystals/archive/%{crystals_rev}.tar.gz#/crystals-%{crystals_rev}.tar.gz
# PATCH-FIX-UPSTREAM not-install-gwavi.patch -- Library only used locally so no need to install this helper
Patch0:         not-install-gwavi.patch
BuildRequires:  cmake >= 3.24
BuildRequires:  eigen3-devel >= 2.91.0
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  hdf5-devel
BuildRequires:  libqt5-linguist-devel
BuildRequires:  mmtf-cpp-devel
BuildRequires:  cmake(Qt5Concurrent)
BuildRequires:  cmake(Qt5Network)
BuildRequires:  cmake(Qt5Svg)
BuildRequires:  cmake(Qt5Widgets)
BuildRequires:  cmake(libmsym) >= 0.2.0
BuildRequires:  pkgconfig(gl)
BuildRequires:  pkgconfig(glew)
BuildRequires:  pkgconfig(libarchive)
BuildRequires:  pkgconfig(zlib)
%if %{with python}
BuildRequires:  python3-devel
BuildRequires:  python3-pybind11-devel
%endif
%if %{with spglib}
BuildRequires:  spglib-devel
%endif
%if 0%{?suse_version} <= 1500
BuildRequires:  pkgconfig(glu)
%endif
%if %{with vtk}
BuildRequires:  genXrdPattern
BuildRequires:  cmake(vtk)
%endif

%description
Avogadro libraries provide 3D rendering, visualization, analysis
and data processing useful in computational chemistry, molecular
modeling, bioinformatics, materials science, and related areas.

%package -n %{libname}
Summary:        Avogadro libraries for computational chemistry
Recommends:     avogadro2-data >= %{version}
Recommends:     %{name}-plugins >= %{version}

%description -n %{libname}
Avogadro libraries provide 3D rendering, visualization, analysis
and data processing useful in computational chemistry, molecular
modeling, bioinformatics, materials science, and related areas.

%package plugins
Summary:        Plugins for Avogadro2libs

%description plugins
This package contains the vendor provided plugins for Avogadro2

%package -n avogadro2-data
Summary:        Data files for Avogadro2 and Avogadro2libs
BuildArch:      noarch

%description -n avogadro2-data
This package contains:
  * Crystallographic files of common materials, elements, oxides, for visualization in Avogadro.
  * Common molecule fragments for visualization in Avogadro

%package devel
Summary:        Header files for Avogadro libraries
Requires:       %{libname} = %{version}
Requires:       %{name}-plugins = %{version}
Requires:       cmake(MoleQueue)
Requires:       cmake(Qt5Network)
Requires:       cmake(Qt5Widgets)
Requires:       pkgconfig(gl)
Requires:       pkgconfig(glew)
%if 0%{?suse_version} <= 1500
Requires:       pkgconfig(glu)
%endif

%description devel
Header files for Avogadro libraries.

%if %{with python}
%package -n python3-avogadro
Summary:        Python bindings for Avogadro libraries

%description -n python3-avogadro
Avogadro libraries provide 3D rendering, visualization, analysis
and data processing useful in computational chemistry, molecular
modeling, bioinformatics, materials science, and related areas.
%endif

%prep
%setup -q -b 1 -b 2
%autopatch -p1
[ -e ../crystals ] && rm -rfv ../crystals; mv ../crystals-%{crystals_rev} ../crystals
[ -e ../molecules ] && rm -rfv ../molecules; mv ../molecules-%{molecules_rev} ../molecules
%ifarch aarch64 %{arm}
# Workaround for Qt GLES builds on ARM, until overlayaxes fixed upstream - https://github.com/OpenChemistry/avogadrolibs/issues/810
# Type of function prototypes differ between GLEW and GLES
sed -i 's/add_subdirectory(overlayaxes)//' avogadro/qtplugins/CMakeLists.txt
%endif

%build
%cmake \
  -DINSTALL_DOC_DIR:PATH=%{_defaultdocdir} \
  -DBUILD_STATIC_PLUGINS:BOOL=OFF \
  -DENABLE_TRANSLATIONS:BOOL=ON \
  -DUSE_MOLEQUEUE:BOOL=ON \
  -DUSE_LIBMSYM:BOOL=ON \
  -DUSE_MMTF:BOOL=ON \
  -DUSE_HDF5:BOOL=ON \
  -DUSE_QT:BOOL=ON \
  -DUSE_VTK:BOOL=%{?with_vtk:ON}%{!?with_vtk:OFF} \
  -DUSE_PYTHON:BOOL=%{?with_python:ON}%{!?with_python:OFF} \
  -DUSE_SPGLIB:BOOL=%{?with_spglib:ON}%{!?with_spglib:OFF} \
  -DOpenGL_GL_PREFERENCE=GLVND \
  %{nil}
%cmake_build

%install
%cmake_install
rm %{buildroot}%{_defaultdocdir}/avogadrolibs/LICENSE
%fdupes %{buildroot}%{_datadir}

sed -i -e '1 s@^@#!/usr/bin/python3\n@' \
  %{buildroot}%{_libdir}/avogadro2/scripts/charges/*.py \
  %{buildroot}%{_libdir}/avogadro2/scripts/formatScripts/zyx.py

# Remove exec permissions from scripts not in $$PATH
chmod -x %{buildroot}%{_libdir}/avogadro2/scripts/energy/*.py

%post -n %{libname} -p /sbin/ldconfig

%postun -n %{libname} -p /sbin/ldconfig

%files -n %{libname}
%license LICENSE
%{_libdir}/libAvogadro*.so.%{sonum}*

%files plugins
%dir %{_libdir}/avogadro2
%{_libdir}/avogadro2/{plugins,scripts}

%files devel
%dir %{_defaultdocdir}/avogadrolibs
%doc %{_defaultdocdir}/avogadrolibs/*.md
%{_includedir}/avogadro/
%{_libdir}/libAvogadro*.so
%{_libdir}/cmake/*

%files -n avogadro2-data
%dir %{_datadir}/avogadro2
%{_datadir}/avogadro2/crystals
%{_datadir}/avogadro2/molecules

%if %{with python}
%files -n python3-avogadro
%{python3_sitearch}/avogadro
%endif

%changelog
* Wed Mar 20 2024 Lubos Kocman <lubos.kocman@suse.com>
- Update licenses based on legaldb scan
* Wed Dec  6 2023 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 1.98.1:
  * Migrated typedefs and changed const to constexpr
    (gh#OpenChemistry/avogadrolibs#1395).
  * Fix Python module install dir
    (gh#OpenChemistry/avogadrolibs#1413).
  * Revert validation of filenames
    (gh#OpenChemistry/avogadrolibs#1433).
  * Parsing orca output would crash when swapping orbitals
    (gh#OpenChemistry/avogadrolibs#1422).
  * Maint: vtk: Add missing OpenGL link target
    (gh#OpenChemistry/avogadrolibs#1412).
- Update molecules and crystals source tarballs to version
  1.98.0.
- Drop upstreamed patches:
  * Fix_qtplugins_surfaces_linking.patch
  * 0001-Avoid-ambigous-definition-of-mmtf-s-is_polymer.patch.
- Minor rebase of not-install-gwavi.patch to apply cleanly.
- Remove executable permissions from scripts not installed to
  $PATH and not expected to be directly executed.
- Bump cmake required version to 3.24 as required by upstream.
* Wed Dec  7 2022 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Fix build with mmtf-cpp 1.1.0, add
  0001-Avoid-ambigous-definition-of-mmtf-s-is_polymer.patch
* Sun Sep 11 2022 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to 1.97.0
  https://github.com/OpenChemistry/avogadrolibs/releases/tag/1.97.0
  Highlights:
  * Adds molecular surfaces, solvent-accessible, and
    solvent-excluded surfaces
  * Adds support for a range of partial charge models, including
    coloring electrostatic potentials on surfaces.
  * This includes writing Python scripts to assign atomic charges
    or electrostatic potential
  * Adds improved hydrogen-bond, chalcogen, and halogen bond
    rendering.
  * Add improved close-contact and salt-bridge rendering
  * Significantly improves interface translation, properly loading
    translation files, and including a dialog to choose your
    preferred user interface language
- Add Fix_qtplugins_surfaces_linking.patch
* Tue Oct 19 2021 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Workaround for Arm/openGL ES, until overlayaxes fixed upstream
  https://github.com/OpenChemistry/avogadrolibs/issues/810
* Thu Oct 14 2021 ecsos <ecsos@opensuse.org>
- Update to 1.95.1
  * Bug Fixes
  - Fix disabled Balls and Sticks rendering on a fresh install (#744)
  - Fix for loading settings (#732)
  - Add ... to all input generators to indicate opening a dialog (#743)
  - Fix reference axes menu item (#705)
  - Continue rendering cartoons even if residues aren't found (#736)
  - Enable script formats like cclib to ask for bond perception on read (#738)
  * Features
  - Initial display-only property tables (#711)
  - Improve selection tool for layers (#729)
  * Maintenance
  - Make sure to run tests in avogadrolibs (including some fix for test failures) (#739)
  * Translations
  - Translations update from Weblate (#721)
- Fix build error for Leap with libmsym >= 0.2.0.
* Mon Aug 30 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 1.95.0
  * Update render options for Wireframe and Ball-and-Sticks
  * Use MMTF downloads - more efficient than PDB format
  * Add back support for importing crystals
  * Add CJSON support for save/load residues and atom colors
  * Detect secondary structure from residues / backbones
  * Remove dependency on MoleQueue (bundled...)
  * Export to SVG
  * OpenMM script builder plugin
  * Allow manipulate to rotate selected fragments
  * Add bestFitPlane on Molecule
  * Transparent support for ASE "extended XYZ" files
  * Switch Open Babel calls to use CML and non-local numeric format
  * Save background color across sessions and set bg alpha for export
  * Add support for a JSON list of selected atoms
  * Update example Avogadro RPC script
  * Fix several crashes with proteins
  * Fix crash in CJSON reading file without labels
  * Fix bug deleting selected atoms
- Add molecules and crystals data files as source, as downloading
  on build time is not possible on OBS
- Drop upstream merged avogadrolibs-spglib-includes.patch
- Split data molecules and crystals data into avogadro2-data package
  and seperated plugins into plugins subpackage
* Sat Aug 21 2021 Dirk Stoecker <opensuse@dstoecker.de>
- Move non-library stuff into it's own package again
* Wed Aug 18 2021 Atri Bhattacharya <badshah400@gmail.com>
- Add avogadrolibs-spglib-includes.patch -- Correct spglib
  includes according to the location spglib headers are installed
  to on openSUSE, which is directly inside %%%%_includedir.
* Wed Aug 18 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- As Factory switched from Avagadro 1 to 2, make factory bot happy
  as patches Fix-build-with-Qt-511.patch, fix-linking-issues.patch,
  fix-gcc-version-check.patch, 0002-create-soversion-libs.patch,
  and use-system-libjsoncpp.patch from old package are not present
  in this package.
* Wed May 26 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 1.93.1
  * Add support for a JSON list of selected atoms
  * Add support for only clearing selected atoms
  * Fix invalid cmake files
  * Fix build with HDF5 >= 1.12.0
  * Fix problems with large molecule
  * Update translations
- Enable building with MoleQueue, mmtf and libmsym they are already
  in Factory and science repository
- Split python into seperate package
- Add not-install-gwavi.patch
- Drop upstream fixed fix_libgwavi_linking.patch
* Wed Feb 12 2020 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- initial version of Avogadro 2 libs
- Fix linking when using BUILD_STATIC_PLUGINS=OFF
  fix_libgwavi_linking.patch
* Sun Jun  3 2018 christophe@krop.fr
- Add Fix-build-with-Qt-511.patch to fix build with Qt 5.11.
* Mon Oct 30 2017 fstrba@suse.com
- Remove the dependency on java-1_8_0-openjdk-devel, since Java is
  apparently not used during the build at all
- Run spec cleaner
* Sat Mar 11 2017 wbauer@tmo.at
- Disable building the GPL-licensed plugins
* Mon Feb  6 2017 jengelh@inai.de
- Choose an *unambiguous* SONAME for shared library as per
  guidelines
* Tue Nov 29 2016 wbauer@tmo.at
- disable molequeue support
- add missing pkgconfig(Qt5Network) BuildRequires
* Mon Nov 28 2016 tittiatcoke@gmail.com
- Update to 0.9.0
  No Changelog available
* Mon Dec 22 2014 alinm.elena@gmail.com
- initial commit
